@@ -9,9 +9,9 @@ from honeybee_schema.energy.programtype import ProgramTypeAbridged, ProgramType
 from honeybee_schema.energy.hvac.idealair import IdealAirSystemAbridged
 from honeybee_schema.energy.hvac.allair import VAV, PVAV, PSZ, PTAC, ForcedAirFurnace
 from honeybee_schema.energy.hvac.doas import FCUwithDOASAbridged, \
-    WSHPwithDOASAbridged, VRFwithDOASAbridged
+    WSHPwithDOASAbridged, VRFwithDOASAbridged, RadiantwithDOASAbridged
 from honeybee_schema.energy.hvac.heatcool import FCU, WSHP, VRF, Baseboard, \
-    EvaporativeCooler, Residential, WindowAC, GasUnitHeater
+    EvaporativeCooler, Residential, WindowAC, GasUnitHeater, Radiant
 from honeybee_schema.energy.ventcool import VentilationControlAbridged, \
     VentilationOpening
 from honeybee_schema.energy.load import ProcessAbridged
@@ -171,7 +171,7 @@ class ModelEnergyProperties(NoExtraBaseModel):
     ] = Field(
         default=None,
         description='A list of all unique constructions in the model. This includes '
-            'constructions across all the Model construction_sets.'
+        'constructions across all the Model construction_sets.'
     )
 
     materials: List[
@@ -192,8 +192,8 @@ class ModelEnergyProperties(NoExtraBaseModel):
         Union[
             IdealAirSystemAbridged, VAV, PVAV, PSZ, PTAC, ForcedAirFurnace,
             FCUwithDOASAbridged, WSHPwithDOASAbridged, VRFwithDOASAbridged,
-            FCU, WSHP, VRF, Baseboard, EvaporativeCooler, Residential,
-            WindowAC, GasUnitHeater
+            RadiantwithDOASAbridged, FCU, WSHP, VRF, Baseboard, EvaporativeCooler,
+            Residential, WindowAC, GasUnitHeater, Radiant
         ]
     ] = Field(
         default=None,
